#!/usr/bin/perl

use strict;
use Test::More;

plan tests => 9;

unlink "dumpfile";
open F, ">cmdfile";
close F;

my $output = `netstat -an | grep 10123 | wc -l`;
chomp $output;
cmp_ok( $output, '==', 0, "Nothing with port 10123");

my $rc = system("../src/nsca -c nsca_test.cfg --single");
cmp_ok( $rc, '==', 0, "nsca started okay");

$output = `netstat -an | grep 10123 | grep LISTEN | wc -l`;
chomp $output;
cmp_ok( $output, '==', 1, "nsca listening on port 10123");

$rc = system('printf "%s\t%s\t%s\n" host 0 "single test" | ../src/send_nsca -H localhost -p 10123 -c send_nsca_test.cfg > /dev/null');
cmp_ok( $rc, "==", 0, "sent packet to nsca");

$output = `netstat -an | grep 10123 | wc -l`;
chomp $output;
cmp_ok( $output, '==', 1, "Still only 1 nsca session");

open CMDFILE, "cmdfile";
my @data = <CMDFILE>;
close CMDFILE;
cmp_ok( scalar @data, '==', 1, "1 line into cmdfile" );
ok( $data[0] =~ /^\[\d+\] PROCESS_HOST_CHECK_RESULT;host;0;single test$/,
	"Got expected data");

my $pid = `ps -U $ENV{USER} | grep nsca | grep -v grep | awk '{print \$1}'`;
chomp $pid;
die "nsca not running" if ($pid eq "");

cmp_ok( (kill 0, $pid), '!=', 0, "nsca running");

kill 15, $pid;
sleep 1;

cmp_ok( (kill 0, $pid), '==', 0, "nsca shutdown");

